#[repr(C)]pub struct Signature {
pub(crate) R: [u8; 32],
pub(crate) s: [u8; 32],
}Expand description
Ed25519 signature.
This type represents a container for the byte serialization of an Ed25519 signature, and does not necessarily represent well-formed field or curve elements.
Signature verification libraries are expected to reject invalid field elements at the time a signature is verified.
Fields
R: [u8; 32]s: [u8; 32]Implementations
Sourceimpl Signature
impl Signature